==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SeriesViewerManipulationEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesViewerManipulationEventArgsDescription } from "./SeriesViewerManipulationEventArgsDescription";
/**
 * @hidden
 */
var SeriesViewerManipulationEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesViewerManipulationEventArgsDescriptionMetadata, _super);
    function SeriesViewerManipulationEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesViewerManipulationEventArgsDescriptionMetadata.b = function (a) {
        if (SeriesViewerManipulationEventArgsDescriptionMetadata.a == null) {
            SeriesViewerManipulationEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SeriesViewerManipulationEventArgsDescriptionMetadata.c(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
        }
        if (a.g(SeriesViewerManipulationEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
    };
    SeriesViewerManipulationEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsZoomPan", "Boolean");
        a.item("IsDragZoom", "Boolean");
    };
    SeriesViewerManipulationEventArgsDescriptionMetadata.d = function (a) {
        SeriesViewerManipulationEventArgsDescriptionMetadata.b(a);
        a.u("SeriesViewerManipulationEventArgs", function () { return new SeriesViewerManipulationEventArgsDescription(); });
        a.t("SeriesViewerManipulationEventArgs", SeriesViewerManipulationEventArgsDescriptionMetadata.a);
    };
    SeriesViewerManipulationEventArgsDescriptionMetadata.$t = markType(SeriesViewerManipulationEventArgsDescriptionMetadata, 'SeriesViewerManipulationEventArgsDescriptionMetadata');
    SeriesViewerManipulationEventArgsDescriptionMetadata.a = null;
    return SeriesViewerManipulationEventArgsDescriptionMetadata;
}(Base));
export { SeriesViewerManipulationEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SeriesViewerManipulationEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesViewerManipulationEventArgsDescription } from "./SeriesViewerManipulationEventArgsDescription";
/**
 * @hidden
 */
var SeriesViewerManipulationEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SeriesViewerManipulationEventArgsDescriptionMetadata, _super);
    function SeriesViewerManipulationEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SeriesViewerManipulationEventArgsDescriptionMetadata.b = function (a) {
        if (SeriesViewerManipulationEventArgsDescriptionMetadata.a == null) {
            SeriesViewerManipulationEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SeriesViewerManipulationEventArgsDescriptionMetadata.c(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
        }
        if (a.j(SeriesViewerManipulationEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SeriesViewerManipulationEventArgsDescriptionMetadata.a);
    };
    SeriesViewerManipulationEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsZoomPan", "Boolean");
        a.item("IsDragZoom", "Boolean");
    };
    SeriesViewerManipulationEventArgsDescriptionMetadata.d = function (a) {
        SeriesViewerManipulationEventArgsDescriptionMetadata.b(a);
        a.aa("SeriesViewerManipulationEventArgs", function () { return new SeriesViewerManipulationEventArgsDescription(); });
        a.z("SeriesViewerManipulationEventArgs", SeriesViewerManipulationEventArgsDescriptionMetadata.a);
    };
    SeriesViewerManipulationEventArgsDescriptionMetadata.$t = markType(SeriesViewerManipulationEventArgsDescriptionMetadata, 'SeriesViewerManipulationEventArgsDescriptionMetadata');
    SeriesViewerManipulationEventArgsDescriptionMetadata.a = null;
    return SeriesViewerManipulationEventArgsDescriptionMetadata;
}(Base));
export { SeriesViewerManipulationEventArgsDescriptionMetadata };
